Module: UsableConfig

Defined in:
lib/ubiquitous_user.rb

Overview

Copyright 2010 J. Pablo Fernández

Class Method Summary collapse

Class Method Details

.user_modelObject

Class that defines the user model.



11
12
13
# File 'lib/ubiquitous_user.rb', line 11

def user_model
  @user_model
end

.user_model=(value) ⇒ Object

Class that defines the user model.



11
12
13
# File 'lib/ubiquitous_user.rb', line 11

def user_model=(value)
  @user_model = value
end

.user_model_classObject

:nodoc:



23
24
25
# File 'lib/ubiquitous_user.rb', line 23

def user_model_class  # :nodoc:
  Object.const_get(user_model)
end

.user_model_nameObject

Method used to get the name of the user.



20
21
22
# File 'lib/ubiquitous_user.rb', line 20

def user_model_name
  @user_model_name
end

.user_model_name=(value) ⇒ Object

Method used to get the name of the user.



20
21
22
# File 'lib/ubiquitous_user.rb', line 20

def user_model_name=(value)
  @user_model_name = value
end

.user_model_newObject

Method used to create a new user, of class user_model



14
15
16
# File 'lib/ubiquitous_user.rb', line 14

def user_model_new
  @user_model_new
end

.user_model_new=(value) ⇒ Object

Method used to create a new user, of class user_model



14
15
16
# File 'lib/ubiquitous_user.rb', line 14

def user_model_new=(value)
  @user_model_new = value
end

.user_model_saveObject

Method used to save the user.



17
18
19
# File 'lib/ubiquitous_user.rb', line 17

def user_model_save
  @user_model_save
end

.user_model_save=(value) ⇒ Object

Method used to save the user.



17
18
19
# File 'lib/ubiquitous_user.rb', line 17

def user_model_save=(value)
  @user_model_save = value
end